@@ -1,4 +1,3 @@
-# $Id: Simple.pm,v 1.6 2005/02/21 23:50:37 dstuart Exp $
 ###############################################################################
 #
 # File:    Simple.pm
@@ -21,7 +20,7 @@ require DynaLoader;
 
 our @ISA = qw(DynaLoader);
 
-our $VERSION = '0.32';
+our $VERSION = '0.42';
 
 bootstrap Authen::Krb5::Simple $VERSION;
 
@@ -44,10 +43,11 @@ sub authenticate {
     my $user = shift || croak "Missing arg: username\n";
     my $pw   = shift; 
 
-    croak "Missing arg: password\n" unless(defined($pw));
+    if(!defined($pw) or $pw eq '') {
+        # Codes staring with 'e' are internal to this module.
+        #
+        $self->{_err_code} = 'e1';
 
-    if($pw eq '') {
-        carp "Empty passwords are not supported.\n" if($pw eq '');
         return 0;
     }
 
@@ -58,31 +58,37 @@ sub authenticate {
         $user .= "\@$self->{_realm}";
     }
 
-    return(($self->{_err_code} = krb5_auth($user, $pw)) == 0);
+    $self->{_err_code} = krb5_auth($user, $pw);
+
+    return(($self->{_err_code} == 0) ? 1 : 0);
 }
 
 # Return the error string from the most recent authenticate function.
 #
 sub errstr {
-    my $self = shift;
+    # Check for module internal (non-krb) error. If it is return the
+    # appropriate error string (there is only one at present).
+    #
+    if($_[0]->{_err_code} =~ /^e(\d+)/) {
+        return('Null or empty password not supported') if($1 == 1);
+    }
 
-    return '' if($self->{_err_code} == 0);
-
-    return krb5_errstr($self->{_err_code});
+    # Otherwise, let krb5_errstr tell us...
+    #
+    return ($_[0]->{_err_code} == 0) ? '' : krb5_errstr($_[0]->{_err_code});
 }
 
 # Return the error code from the most recent authenticate function.
 #
 sub errcode {
-    my $self = shift;
-    return $self->{_err_code};
+    return $_[0]->{_err_code};
 }
 
 # Get or set the default realm
 #
 sub realm {
-    my $self    = shift;
-    my $arg     = shift;
+    my $self = shift;
+    my $arg  = shift;
 
     $self->{_realm} = $arg if(defined($arg));
 
@@ -125,7 +131,7 @@ Authen::Krb5::Simple - Basic user authentication using Kerberos 5
 
   # Create a new object pointing to another realm.
   #
-  my $alt_krb = Authen::Krb5::Simple->new(realm => 'new.realm');
+  my $alt_krb = Authen::Krb5::Simple->new(realm => 'OTHER.REALM');
   ...
 
 =head1 DESCRIPTION
@@ -137,8 +143,8 @@ that user using the local Kerberos 5 installation.  It was initially created
 to allow perl scripts to perform authentication against a Microsoft Active
 Directory (AD) server configured to accept Kerberos client requests.
 
-B<It is important to note:> This module only performs simple authentication.  It
-does not get, grant, use, or retain any kerberos tickets.  It will check
+B<It is important to note:> This module only performs simple authentication.
+It does not get, grant, use, or retain any kerberos tickets.  It will check
 user credentials against the Kerberos server (as configured on the local
 system) each time the I<authenticate> method is called.
 
@@ -189,12 +195,14 @@ object.
         
 =back
    
-B<realm([NEW.REALM])>
+B<realm( )>
+
+B<realm(NEW.REALM)>
 
 =over
 
 The I<realm> method is used to set or get the current default realm.  If an
-argument is passed to this method, the default realm is set to its value. If
+argument is passed to this method, the default realm is set to that value. If
 no argument is supplied, the current realm is returned.
 
 =back
@@ -220,14 +228,14 @@ I<errstr> method to get a meaningful error message.
 
 =head1 BUGS
 
-This version of I<Authen::Krb5::Simple> does not support empty passwords.
-If you pass an empty string (C<''>) as a password, I<authenticate> will print
-a warning and return false, but there will be no error code or string returned
-if the I<errstr> method is called.
+This version of I<Authen::Krb5::Simple> does not support null or
+empty passwords.  If you pass an undefined value or empty string (C<''>)
+as a password, I<authenticate> return false and set the error to indicate
+that null or empty passwords are not supported.
 
 =head1 AUTHOR
 
-Damien S. Stuart, E<lt>damien.stuart@usi.netE<gt>
+Damien S. Stuart, E<lt>dstuart@dstuart.orgE<gt>
 
 =head1 SEE ALSO
 
